% Auto-generated chapter 13 for tirmidhi
% Hadiths in this chapter: 31

\hadithdefcmd{tirmidhi}{1175}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، قَالَ سَأَلْتُ ابْنَ عُمَرَ عَنْ رَجُلٍ، طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَقَالَ هَلْ تَعْرِفُ عَبْدَ اللَّهِ بْنَ عُمَرَ فَإِنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَسَأَلَ عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهُ أَنْ يُرَاجِعَهَا ‏.‏ قَالَ قُلْتُ فَيُعْتَدُّ بِتِلْكَ التَّطْلِيقَةِ قَالَ فَمَهْ أَرَأَيْتَ إِنْ عَجَزَ وَاسْتَحْمَقَ\hadithno{1175}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Yunus bin Jubair said:"I asked Ibn Umar about a man who divorced his wife while she was menstruating. So he said: 'Don't you know Abdullah bin Umar?' Indeed he divorced his wife while she was menstruating, so Umar asked the Prophet about that, and he ordered him to take her back.'" He said: "I said: And that divorce is counted? He said: And that divorce is counted? He said: 'What else would you think if he was helpless and foolish?}}
\hadithdefcmd{tirmidhi}{1176}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى آلِ طَلْحَةَ عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ طَلَّقَ امْرَأَتَهُ فِي الْحَيْضِ فَسَأَلَ عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيُطَلِّقْهَا طَاهِرًا أَوْ حَامِلاً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ يُونُسَ بْنِ جُبَيْرٍ عَنِ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَكَذَلِكَ حَدِيثُ سَالِمٍ عَنِ ابْنِ عُمَرَ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ طَلاَقَ السُّنَّةِ أَنْ يُطَلِّقَهَا طَاهِرًا مِنْ غَيْرِ جِمَاعٍ ‏.‏ وَقَالَ بَعْضُهُمْ إِنْ طَلَّقَهَا ثَلاَثًا وَهِيَ طَاهِرٌ فَإِنَّهُ يَكُونُ لِلسُّنَّةِ أَيْضًا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ بْنِ حَنْبَلٍ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ تَكُونُ ثَلاَثًا لِلسُّنَّةِ إِلاَّ أَنْ يُطَلِّقَهَا وَاحِدَةً وَاحِدَةً ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَإِسْحَاقَ ‏.‏ وَقَالُوا فِي طَلاَقِ الْحَامِلِ يُطَلِّقُهَا مَتَى شَاءَ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ يُطَلِّقُهَا عِنْدَ كُلِّ شَهْرٍ تَطْلِيقَةً ‏.‏\hadithno{1176}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salim narrated that:His father divorced his wife during her menses, so Umar asked the Prophet about that and he said: "Tell him to take her back, then let him divorce her while she is pure or pregnant}}
\hadithdefcmd{tirmidhi}{1177}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا قَبِيصَةُ، عَنْ جَرِيرِ بْنِ حَازِمٍ، عَنِ الزُّبَيْرِ بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ بْنِ رُكَانَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي طَلَّقْتُ امْرَأَتِي الْبَتَّةَ ‏.‏ فَقَالَ ‏"‏ مَا أَرَدْتَ بِهَا ‏"‏ ‏.‏ قُلْتُ وَاحِدَةً ‏.‏ قَالَ ‏"‏ وَاللَّهِ ‏"‏ ‏.‏ قُلْتُ وَاللَّهِ ‏.‏ قَالَ ‏"‏ فَهُوَ مَا أَرَدْتَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ فِيهِ اضْطِرَابٌ ‏.‏ وَيُرْوَى عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ أَنَّ رُكَانَةَ طَلَّقَ امْرَأَتَهُ ثَلاَثًا ‏.‏ - وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي طَلاَقِ الْبَتَّةِ فَرُوِيَ عَنْ عُمَرَ بْنِ الْخَطَّابِ أَنَّهُ جَعَلَ الْبَتَّةَ وَاحِدَةً وَرُوِيَ عَنْ عَلِيٍّ أَنَّهُ جَعَلَهَا ثَلاَثًا ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ فِيهِ نِيَّةُ الرَّجُلِ إِنْ نَوَى وَاحِدَةً فَوَاحِدَةٌ وَإِنْ نَوَى ثَلاَثًا فَثَلاَثٌ وَإِنْ نَوَى ثِنْتَيْنِ لَمْ تَكُنْ إِلاَّ وَاحِدَةً ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏ وَقَالَ مَالِكُ بْنُ أَنَسٍ فِي الْبَتَّةِ إِنْ كَانَ قَدْ دَخَلَ بِهَا فَهِيَ ثَلاَثُ تَطْلِيقَاتٍ ‏.‏ وَقَالَ الشَّافِعِيُّ إِنْ نَوَى وَاحِدَةً فَوَاحِدَةٌ يَمْلِكُ الرَّجْعَةَ وَإِنْ نَوَى ثِنْتَيْنِ فَثِنْتَانِ وَإِنْ نَوَى ثَلاَثًا فَثَلاَثٌ ‏.‏\hadithno{1177}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Yazid bin Rukanah narrated from his father, from his grandfather who said:'O Messenger of Allah! I irrevocably divorced my wife.' So he said: 'What did you intend by that?' I said: 'One (divorce).' He said: '(Do you swear) By Allah?' I said: 'By Allah.' He said: 'Then it is as you intended}}
\hadithdefcmd{tirmidhi}{1178}{حَدَّثَنَا عَلِيُّ بْنُ نَصْرِ بْنِ عَلِيٍّ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ قُلْتُ لأَيُّوبَ هَلْ عَلِمْتَ أَنَّ أَحَدًا قَالَ فِي أَمْرُكِ بِيَدِكِ أَنَّهَا ثَلاَثٌ إِلاَّ الْحَسَنَ فَقَالَ لاَ إِلاَّ الْحَسَنَ ‏.‏ ثُمَّ قَالَ اللَّهُمَّ غَفْرًا إِلاَّ مَا حَدَّثَنِي قَتَادَةُ عَنْ كَثِيرٍ مَوْلَى ابْنِ سَمُرَةَ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثٌ ‏"‏ ‏.‏ قَالَ أَيُّوبُ فَلَقِيتُ كَثِيرًا - مَوْلَى ابْنِ سَمُرَةَ فَسَأَلْتُهُ فَلَمْ يَعْرِفْهُ فَرَجَعْتُ إِلَى قَتَادَةَ فَأَخْبَرْتُهُ فَقَالَ نَسِيَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ سُلَيْمَانَ بْنِ حَرْبٍ عَنْ حَمَّادِ بْنِ زَيْدٍ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ، فَقَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، عَنْ حَمَّادِ بْنِ زَيْدٍ، بِهَذَا وَإِنَّمَا هُوَ عَنْ أَبِي هُرَيْرَةَ، مَوْقُوفٌ ‏.‏ وَلَمْ يُعْرَفْ حَدِيثُ أَبِي هُرَيْرَةَ مَرْفُوعًا ‏.‏ وَكَانَ عَلِيُّ بْنُ نَصْرٍ حَافِظًا صَاحِبَ حَدِيثٍ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي أَمْرُكِ بِيَدِكِ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ وَعَبْدُ اللَّهِ بْنُ مَسْعُودٍ هِيَ وَاحِدَةٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ وَمَنْ بَعْدَهُمْ ‏.‏ وَقَالَ عُثْمَانُ بْنُ عَفَّانَ وَزَيْدُ بْنُ ثَابِتٍ الْقَضَاءُ مَا قَضَتْ ‏.‏ وَقَالَ ابْنُ عُمَرَ إِذَا جَعَلَ أَمْرَهَا بِيَدِهَا وَطَلَّقَتْ نَفْسَهَا ثَلاَثًا وَأَنْكَرَ الزَّوْجُ وَقَالَ لَمْ أَجْعَلْ أَمْرَهَا بِيَدِهَا إِلاَّ فِي وَاحِدَةٍ اسْتُحْلِفَ الزَّوْجُ وَكَانَ الْقَوْلُ قَوْلَهُ مَعَ يَمِينِهِ ‏.‏ وَذَهَبَ سُفْيَانُ وَأَهْلُ الْكُوفَةِ إِلَى قَوْلِ عُمَرَ وَعَبْدِ اللَّهِ ‏.‏ وَأَمَّا مَالِكُ بْنُ أَنَسٍ فَقَالَ الْقَضَاءُ مَا قَضَتْ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ ‏.‏ وَأَمَّا إِسْحَاقُ فَذَهَبَ إِلَى قَوْلِ ابْنِ عُمَرَ ‏.‏\hadithno{1178}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Hammad bin Yazid said:"I said to Abu Ayyub: 'Do you know of anyone who said that: "Your case is up to you?" counts as three besides Al-Hasan?' He said: "No, not besides Al-Hasan.' Then he said: 'O Allah forgive me - except for what has been narrated to me by Qatadah, from Kathir the freed slave of Banu Samurah, from Abu Salamah, from Abu Hurairah, that the Prophet said: "Three.'"Abu Ayyub said: 'So I met Kathir the freed slave of Banu Samurah and asked him about it, but he was not aware of it. So I returned to Qatadah and informed him about that and he said: "He forgot}}
\hadithdefcmd{tirmidhi}{1179}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَرْنَاهُ أَفَكَانَ طَلاَقًا؟ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، بِمِثْلِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْخِيَارِ فَرُوِيَ عَنْ عُمَرَ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ أَنَّهُمَا قَالاَ إِنِ اخْتَارَتْ نَفْسَهَا فَوَاحِدَةٌ بَائِنَةٌ ‏.‏ وَرُوِيَ عَنْهُمَا أَنَّهُمَا قَالاَ أَيْضًا وَاحِدَةٌ يَمْلِكُ الرَّجْعَةَ وَإِنِ اخْتَارَتْ زَوْجَهَا فَلاَ شَىْءَ ‏.‏ وَرُوِيَ عَنْ عَلِيٍّ أَنَّهُ قَالَ إِنِ اخْتَارَتْ نَفْسَهَا فَوَاحِدَةٌ بَائِنَةٌ وَإِنِ اخْتَارَتْ زَوْجَهَا فَوَاحِدَةٌ يَمْلِكُ الرَّجْعَةَ ‏.‏ وَقَالَ زَيْدُ بْنُ ثَابِتٍ إِنِ اخْتَارَتْ زَوْجَهَا فَوَاحِدَةٌ وَإِنِ اخْتَارَتْ نَفْسَهَا فَثَلاَثٌ ‏.‏ وَذَهَبَ أَكْثَرُ أَهْلِ الْعِلْمِ وَالْفِقْهِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ فِي هَذَا الْبَابِ إِلَى قَوْلِ عُمَرَ وَعَبْدِ اللَّهِ وَهُوَ قَوْلُ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَأَمَّا أَحْمَدُ بْنُ حَنْبَلٍ فَذَهَبَ إِلَى قَوْلِ عَلِيٍّ رضى الله عنه ‏.‏\hadithno{1179}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah said:"The Messenger of Allah gave us the choice, so we chose him. So was that a divorce?}}
\hadithdefcmd{tirmidhi}{1180}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، قَالَ قَالَتْ فَاطِمَةُ بِنْتُ قَيْسٍ طَلَّقَنِي زَوْجِي ثَلاَثًا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ سُكْنَى لَكِ وَلاَ نَفَقَةَ ‏"‏ ‏.‏ قَالَ مُغِيرَةُ فَذَكَرْتُهُ لإِبْرَاهِيمَ فَقَالَ قَالَ عُمَرُ لاَ نَدَعُ كِتَابَ اللَّهِ وَسُنَّةَ نَبِيِّنَا صلى الله عليه وسلم لِقَوْلِ امْرَأَةٍ لاَ نَدْرِي أَحَفِظَتْ أَمْ نَسِيَتْ ‏.‏ وَكَانَ عُمَرُ يَجْعَلُ لَهَا السُّكْنَى وَالنَّفَقَةَ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَنْبَأَنَا حُصَيْنٌ، وَإِسْمَاعِيلُ، وَمُجَالِدٌ، قَالَ هُشَيْمٌ وَحَدَّثَنَا دَاوُدُ، أَيْضًا عَنِ الشَّعْبِيِّ، قَالَ دَخَلْتُ عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ فَسَأَلْتُهَا عَنْ قَضَاءِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهَا فَقَالَتْ طَلَّقَهَا زَوْجُهَا الْبَتَّةَ فَخَاصَمَتْهُ فِي السُّكْنَى وَالنَّفَقَةِ فَلَمْ يَجْعَلْ لَهَا النَّبِيُّ صلى الله عليه وسلم سُكْنَى وَلاَ نَفَقَةً ‏.‏ وَفِي حَدِيثِ دَاوُدَ قَالَتْ وَأَمَرَنِي أَنْ أَعْتَدَّ فِي بَيْتِ ابْنِ أُمِّ مَكْتُومٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ بَعْضِ أَهْلِ الْعِلْمِ مِنْهُمُ الْحَسَنُ الْبَصْرِيُّ وَعَطَاءُ بْنُ أَبِي رَبَاحٍ وَالشَّعْبِيُّ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالُوا لَيْسَ لِلْمُطَلَّقَةِ سُكْنَى وَلاَ نَفَقَةٌ إِذَا لَمْ يَمْلِكْ زَوْجُهَا الرَّجْعَةَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ وَعَبْدُ اللَّهِ إِنَّ الْمُطَلَّقَةَ ثَلاَثًا لَهَا السُّكْنَى وَالنَّفَقَةُ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لَهَا السُّكْنَى وَلاَ نَفَقَةَ لَهَا ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَاللَّيْثِ بْنِ سَعْدٍ وَالشَّافِعِيِّ ‏.‏ وَقَالَ الشَّافِعِيُّ إِنَّمَا جَعَلْنَا لَهَا السُّكْنَى بِكِتَابِ اللَّهِ قَالَ اللَّهُ تَعَالَى‏:‏ ‏(‏لاَ تُخْرِجُوهُنَّ مِنْ بُيُوتِهِنَّ وَلاَ يَخْرُجْنَ إِلاَّ أَنْ يَأْتِينَ بِفَاحِشَةٍ مُبَيِّنَةٍ ‏)‏ قَالُوا هُوَ الْبَذَاءُ أَنْ تَبْذُوَ عَلَى أَهْلِهَا ‏.‏ وَاعْتَلَّ بِأَنَّ فَاطِمَةَ بِنْتَ قَيْسٍ لَمْ يَجْعَلْ لَهَا النَّبِيُّ صلى الله عليه وسلم السُّكْنَى لِمَا كَانَتْ تَبْذُو عَلَى أَهْلِهَا ‏.‏ قَالَ الشَّافِعِيُّ وَلاَ نَفَقَةَ لَهَا لِحَدِيثِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي قِصَّةِ حَدِيثِ فَاطِمَةَ بِنْتِ قَيْسٍ ‏.‏\hadithno{1180}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Fatimah bint Qais said:"My husband divorced me three times during the time of the Prophet. So the Messenger of Allah said: 'There is no housing for you nor maintenance.'" Al-Mughirah (one of the narrators) said: "I mentioned that to Ibrahim and he said: Umar said: "We do not leave the Book of Allah and the Sunnah of our Prophet for the saying of a woman, and we do not know if she remembered or forgot." And Umar used to give her (the divorced woman) housing and maintenance}}
\hadithdefcmd{tirmidhi}{1181}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا عَامِرٌ الأَحْوَلُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ لاِبْنِ آدَمَ فِيمَا لاَ يَمْلِكُ وَلاَ عِتْقَ لَهُ فِيمَا لاَ يَمْلِكُ وَلاَ طَلاَقَ لَهُ فِيمَا لاَ يَمْلِكُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَمُعَاذِ بْنِ جَبَلٍ وَجَابِرٍ وَابْنِ عَبَّاسٍ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو حَدِيثٌ حَسَنٌ صَحِيحٌ وَهُوَ أَحْسَنُ شَيْءٍ رُوِيَ فِي هَذَا الْبَابِ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ رُوِيَ ذَلِكَ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ وَابْنِ عَبَّاسٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَسَعِيدِ بْنِ الْمُسَيَّبِ وَالْحَسَنِ وَسَعِيدِ بْنِ جُبَيْرٍ وَعَلِيِّ بْنِ الْحُسَيْنِ وَشُرَيْحٍ وَجَابِرِ بْنِ زَيْدٍ وَغَيْرِ وَاحِدٍ مِنْ فُقَهَاءِ التَّابِعِينَ وَبِهِ يَقُولُ الشَّافِعِيُّ ‏.‏ وَرُوِيَ عَنِ ابْنِ مَسْعُودٍ أَنَّهُ قَالَ فِي الْمَنْصُوبَةِ إِنَّهَا تَطْلُقُ ‏.‏ وَقَدْ رُوِيَ عَنْ إِبْرَاهِيمَ النَّخَعِيِّ وَالشَّعْبِيِّ وَغَيْرِهِمَا مِنْ أَهْلِ الْعِلْمِ أَنَّهُمْ قَالُوا إِذَا وَقَّتَ نُزِّلَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ أَنَّهُ إِذَا سَمَّى امْرَأَةً بِعَيْنِهَا أَوْ وَقَّتَ وَقْتًا أَوْ قَالَ إِنْ تَزَوَّجْتُ مِنْ كُورَةِ كَذَا فَإِنَّهُ إِنْ تَزَوَّجَ فَإِنَّهَا تَطْلُقُ ‏.‏ وَأَمَّا ابْنُ الْمُبَارَكِ فَشَدَّدَ فِي هَذَا الْبَابِ وَقَالَ إِنْ فَعَلَ لاَ أَقُولُ هِيَ حَرَامٌ ‏.‏ وَقَالَ أَحْمَدُ إِنْ تَزَوَّجَ لاَ آمُرُهُ أَنْ يُفَارِقَ امْرَأَتَهُ ‏.‏ وَقَالَ إِسْحَاقُ أَنَا أُجِيزُ فِي الْمَنْصُوبَةِ لِحَدِيثِ ابْنِ مَسْعُودٍ وَإِنْ تَزَوَّجَهَا لاَ أَقُولُ تَحْرُمُ عَلَيْهِ امْرَأَتُهُ ‏.‏ وَوَسَّعَ إِسْحَاقُ فِي غَيْرِ الْمَنْصُوبَةِ ‏.‏ وَذُكِرَ عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ أَنَّهُ سُئِلَ عَنْ رَجُلٍ حَلَفَ بِالطَّلاَقِ أَنَّهُ لاَ يَتَزَوَّجُ ثُمَّ بَدَا لَهُ أَنْ يَتَزَوَّجَ هَلْ لَهُ رُخْصَةٌ بِأَنْ يَأْخُذَ بِقَوْلِ الْفُقَهَاءِ الَّذِينَ رَخَّصُوا فِي هَذَا فَقَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ إِنْ كَانَ يَرَى هَذَا الْقَوْلَ حَقًّا مِنْ قَبْلِ أَنْ يُبْتَلَى بِهَذِهِ الْمَسْأَلَةِ فَلَهُ أَنْ يَأْخُذَ بِقَوْلِهِمْ فَأَمَّا مَنْ لَمْ يَرْضَ بِهَذَا فَلَمَّا ابْتُلِيَ أَحَبَّ أَنْ يَأْخُذَ بِقَوْلِهِمْ فَلاَ أَرَى لَهُ ذَلِكَ ‏.‏\hadithno{1181}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib narrated from his grandfather, from his father, that:The Messenger of Allah said: "There is no vow for the son of Adam over what he has no control, and there is no emancipating he can do for one whom he does not own, and there is no divorce for him regarding that which he has no control over}}
\hadithdefcmd{tirmidhi}{1182}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي مُظَاهِرُ بْنُ أَسْلَمَ، قَالَ حَدَّثَنِي الْقَاسِمُ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ طَلاَقُ الأَمَةِ تَطْلِيقَتَانِ وَعِدَّتُهَا حَيْضَتَانِ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى وَحَدَّثَنَا أَبُو عَاصِمٍ، أَنْبَأَنَا مُظَاهِرٌ، بِهَذَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ مُظَاهِرِ بْنِ أَسْلَمَ وَمُظَاهِرٌ لاَ نَعْرِفُ لَهُ فِي الْعِلْمِ غَيْرَ هَذَا الْحَدِيثِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1182}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muzahir bin Aslam narrated that Al-Qasim narrated from Aishah that:The Messenger of Allah said: "The divorce for a slave woman is two divorces, and her Iddah is two menstruations}}
\hadithdefcmd{tirmidhi}{1183}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَجَاوَزَ اللَّهُ لأُمَّتِي مَا حَدَّثَتْ بِهِ أَنْفُسَهَا مَا لَمْ تَكَلَّمْ بِهِ أَوْ تَعْمَلْ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الرَّجُلَ إِذَا حَدَّثَ نَفْسَهُ بِالطَّلاَقِ لَمْ يَكُنْ شَيْءٌ حَتَّى يَتَكَلَّمَ بِهِ ‏.‏\hadithno{1183}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narraed that:The Messenger of Allah said: "Allah has permitted my Ummah what occurs in their mines, as long as it is not spoken or acted upon}}
\hadithdefcmd{tirmidhi}{1184}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَرْدَكَ، عَنْ عَطَاءٍ، عَنِ ابْنِ مَاهَكَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثٌ جِدُّهُنَّ جِدٌّ وَهَزْلُهُنَّ جِدٌّ النِّكَاحُ وَالطَّلاَقُ وَالرَّجْعَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏ قَالَ أَبُو عِيسَى وَعَبْدُ الرَّحْمَنِ هُوَ ابْنُ حَبِيبِ بْنِ أَرْدَكَ الْمَدَنِيُّ وَابْنُ مَاهَكَ هُوَ عِنْدِي يُوسُفُ بْنُ مَاهَكَ ‏.‏\hadithno{1184}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "Three are serious when they are serious, and serious when they are in jest: Marriage, divorce, and return}}
\hadithdefcmd{tirmidhi}{1185}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ سُفْيَانَ، أَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، وَهُوَ مَوْلَى آلِ طَلْحَةَ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ بْنِ عَفْرَاءَ، أَنَّهَا اخْتَلَعَتْ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم - أَوْ أُمِرَتْ - أَنْ تَعْتَدَّ بِحَيْضَةٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الرُّبَيِّعِ الصَّحِيحُ أَنَّهَا أُمِرَتْ أَنْ تَعْتَدَّ بِحَيْضَةٍ ‏.‏\hadithno{1185}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{AR-Rubayyi bint Mu'awwidh bin Al-Afra narrated:that she got a Khul during the time of the Prophet. So the Prophet ordered her - or: she was ordered - that she observe an Iddah of a menstruation}}
\hadithdefcmd{tirmidhi}{1185p2}{أَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ الْبَغْدَادِيُّ، أَنْبَأَنَا عَلِيُّ بْنُ بَحْرٍ، أَنْبَأَنَا هِشَامُ بْنُ يُوسُفَ، عَنْ مَعْمَرٍ، عَنْ عَمْرِو بْنِ مُسْلِمٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةَ، ثَابِتِ بْنِ قَيْسٍ اخْتَلَعَتْ مِنْ زَوْجِهَا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم أَنْ تَعْتَدَّ بِحَيْضَةٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي عِدَّةِ الْمُخْتَلِعَةِ فَقَالَ أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِنَّ عِدَّةَ الْمُخْتَلِعَةِ عِدَّةُ الْمُطَلَّقَةِ ثَلاَثُ حِيَضٍ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِنَّ عِدَّةَ الْمُخْتَلِعَةِ حَيْضَةٌ ‏.‏ قَالَ إِسْحَاقُ وَإِنْ ذَهَبَ ذَاهِبٌ إِلَى هَذَا فَهُوَ مَذْهَبٌ قَوِيٌّ ‏.‏\hadithno{1185.2}\hadithtrans{Ibn Abbas narrated that :The wife of Thabit bin Qais was granted a Khul from her husband during the time of the Prophet. So the Prophet ordered her to observe an Iddah of a menstruation}}
\hadithdefcmd{tirmidhi}{1186}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُزَاحِمُ بْنُ ذَوَّادِ بْنِ عُلْبَةَ، عَنْ أَبِيهِ، عَنْ لَيْثٍ، عَنْ أَبِي الْخَطَّابِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي إِدْرِيسَ، عَنْ ثَوْبَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْمُخْتَلِعَاتُ هُنَّ الْمُنَافِقَاتُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ أَيُّمَا امْرَأَةٍ اخْتَلَعَتْ مِنْ زَوْجِهَا مِنْ غَيْرِ بَأْسٍ لَمْ تَرِحْ رَائِحَةَ الْجَنَّةِ ‏"‏\hadithno{1186}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Thawban narrated that:The Prophet said: "The women who seek a Khul are hypocrites}}
\hadithdefcmd{tirmidhi}{1187}{أَنْبَأَنَا بِذَلِكَ بُنْدَارٌ أَنْبَأَنَا عَبْدُ الْوَهَّابِ أَنْبَأَنَا أَيُّوبُ عَنْ أَبِي قِلاَبَةَ عَمَّنْ حَدَّثَهُ عَنْ ثَوْبَانَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرَأَةٍ سَأَلَتْ زَوْجَهَا طَلاَقًا مِنْ غَيْرِ بَأْسٍ فَحَرَامٌ عَلَيْهَا رَائِحَةُ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَيُرْوَى هَذَا الْحَدِيثُ عَنْ أَيُّوبَ عَنْ أَبِي قِلاَبَةَ عَنْ أَبِي أَسْمَاءَ عَنْ ثَوْبَانَ ‏.‏ وَرَوَاهُ بَعْضُهُمْ عَنْ أَيُّوبَ بِهَذَا الإِسْنَادِ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{1187}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Thawban narrated that :The Messenger of Allah said: "Whichever woman seeks a Khul from her husband without harm (cause), then the scent of Paradise will be unlawful for her}}
\hadithdefcmd{tirmidhi}{1188}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَرْأَةَ كَالضِّلَعِ إِنْ ذَهَبْتَ تُقِيمُهَا كَسَرْتَهَا وَإِنْ تَرَكْتَهَا اسْتَمْتَعْتَ بِهَا عَلَى عِوَجٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي ذَرٍّ وَسَمُرَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1188}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "Indeed the woman is like a rib, if you try to straighten her you will break her, and if you leave her, what you enjoy from her will be with the crookedness}}
\hadithdefcmd{tirmidhi}{1189}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَنْبَأَنَا ابْنُ الْمُبَارَكِ، أَنْبَأَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَتْ تَحْتِي امْرَأَةٌ أُحِبُّهَا وَكَانَ أَبِي يَكْرَهُهَا فَأَمَرَنِي أَبِي أَنْ أُطَلِّقَهَا فَأَبَيْتُ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا عَبْدَ اللَّهِ بْنَ عُمَرَ طَلِّقِ امْرَأَتَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ ابْنِ أَبِي ذِئْبٍ ‏.‏\hadithno{1189}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Umar narrated:"I had a wife whom I loved, but my father disliked her, so he ordered me to divorce her but I refused. I mentioned that to the Prophet and he said: 'O Abdullah bin Umar! Divorce your wife}}
\hadithdefcmd{tirmidhi}{1190}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَسْأَلُ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَكْتَفِئَ مَا فِي إِنَائِهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1190}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:The Prophet said: "No woman should ask for the divorce of her sister (in religion) in order to spill what is in her container}}
\hadithdefcmd{tirmidhi}{1191}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، أَنْبَأَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، عَنْ عَطَاءِ بْنِ عَجْلاَنَ، عَنْ عِكْرِمَةَ بْنِ خَالِدٍ الْمَخْزُومِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ طَلاَقٍ جَائِزٌ إِلاَّ طَلاَقَ الْمَعْتُوهِ الْمَغْلُوبِ عَلَى عَقْلِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ عَطَاءِ بْنِ عَجْلاَنَ ‏.‏ وَعَطَاءُ بْنُ عَجْلاَنَ ضَعِيفٌ ذَاهِبُ الْحَدِيثِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ طَلاَقَ الْمَعْتُوهِ الْمَغْلُوبِ عَلَى عَقْلِهِ لاَ يَجُوزُ إِلاَّ أَنْ يَكُونَ مَعْتُوهًا يُفِيقُ الأَحْيَانَ فَيُطَلِّقُ فِي حَالِ إِفَاقَتِهِ ‏.‏\hadithno{1191}\hadithgrade{Ahmad Muhammad Shakir: Sahih Muquf; Al-Albani: Sahih Muquf; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :The Messenger of Allah said: "Every divorce is valid except the divorce of the Ma'tuh person whose reason is overcome." (Da'if Jiddan)}}
\hadithdefcmd{tirmidhi}{1192}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْلَى بْنُ شَبِيبٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّاسُ وَالرَّجُلُ يُطَلِّقُ امْرَأَتَهُ مَا شَاءَ أَنْ يُطَلِّقَهَا وَهِيَ امْرَأَتُهُ إِذَا ارْتَجَعَهَا وَهِيَ فِي الْعِدَّةِ وَإِنْ طَلَّقَهَا مِائَةَ مَرَّةٍ أَوْ أَكْثَرَ حَتَّى قَالَ رَجُلٌ لاِمْرَأَتِهِ وَاللَّهِ لاَ أُطَلِّقُكِ فَتَبِينِي مِنِّي وَلاَ آوِيكِ أَبَدًا ‏.‏ قَالَتْ وَكَيْفَ ذَاكَ قَالَ أُطَلِّقُكِ فَكُلَّمَا هَمَّتْ عِدَّتُكِ أَنْ تَنْقَضِيَ رَاجَعْتُكِ ‏.‏ فَذَهَبَتِ الْمَرْأَةُ حَتَّى دَخَلَتْ عَلَى عَائِشَةَ فَأَخْبَرَتْهَا فَسَكَتَتْ عَائِشَةُ حَتَّى جَاءَ النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرَتْهُ فَسَكَتَ النَّبِيُّ صلى الله عليه وسلم حَتَّى نَزَلَ الْقُرْآنُ ‏:‏ ‏(‏ الطَّلاَقُ مَرَّتَانِ فَإِمْسَاكٌ بِمَعْرُوفٍ أَوْ تَسْرِيحٌ بِإِحْسَانٍ ‏)‏ قَالَتْ عَائِشَةُ فَاسْتَأْنَفَ النَّاسُ الطَّلاَقَ مُسْتَقْبَلاً مَنْ كَانَ طَلَّقَ وَمَنْ لَمْ يَكُنْ طَلَّقَ ‏.‏ حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، نَحْوَ هَذَا الْحَدِيثِ بِمَعْنَاهُ وَلَمْ يَذْكُرْ فِيهِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنْ حَدِيثِ يَعْلَى بْنِ شَبِيبٍ ‏.‏\hadithno{1192}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Hisham bin Urwah narrated from his father, from Aishah that she said:"The people were such that a man would divorce his wife when he wanted to divorce her, and she remained his wife when he wanted to take her back while she was in her Iddah, and he could divorce a hundred times, or even more, such that a man could say to his wife: 'By Allah! I will neither divorce you irrevocably, nor give you residence ever!' She would say: 'And how is that?' He would say: 'I will divorce you, and whenever your Iddah is just about to end I will take you back. So a woman went to Aishah to inform her about that, and Aishah was silent until the Prophet came. So she told him and the Prophet was silent, until the Qur'an was revealed: Divorce is two times, after that, retain her on reasonable terms or release her with kindness.'" So Aishah said: "So the people could carry on with divorce in the future, (knowing) who was divorced, and who was not divorced}}
\hadithdefcmd{tirmidhi}{1193}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ أَبِي السَّنَابِلِ بْنِ بَعْكَكٍ، قَالَ وَضَعَتْ سُبَيْعَةُ بَعْدَ وَفَاةِ زَوْجِهَا بِثَلاَثَةٍ وَعِشْرِينَ أَوْ خَمْسَةٍ وَعِشْرِينَ يَوْمًا فَلَمَّا تَعَلَّتْ تَشَوَّفَتْ لِلنِّكَاحِ فَأُنْكِرَ عَلَيْهَا ذَلِكَ فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنْ تَفْعَلْ فَقَدْ حَلَّ أَجَلُهَا ‏"‏ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ مَنْصُورٍ، نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ، ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي السَّنَابِلِ حَدِيثٌ مَشْهُورٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَلاَ نَعْرِفُ لِلأَسْوَدِ سَمَاعًا مِنْ أَبِي السَّنَابِلِ ‏.‏ وَسَمِعْتُ مُحَمَّدًا يَقُولُ لاَ أَعْرِفُ أَنَّ أَبَا السَّنَابِلِ عَاشَ بَعْدَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْحَامِلَ الْمُتَوَفَّى عَنْهَا زَوْجُهَا إِذَا وَضَعَتْ فَقَدْ حَلَّ التَّزْوِيجُ لَهَا وَإِنْ لَمْ تَكُنِ انْقَضَتْ عِدَّتُهَا ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ تَعْتَدُّ آخِرَ الأَجَلَيْنِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1193}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Al-Aswad narrated from Abu As-Sanabil bin Ba'kak who said:"Subai'ah delivered twenty-three or twenty-five days after her husband had died. So when she was ready (finished post-natal bleeding) she adorned herself for marriage, but she was rebuked for doing that, so it was mentioned to the Prophet and he said: "If she has done that then her time has come}}
\hadithdefcmd{tirmidhi}{1194}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ أَبَا هُرَيْرَةَ، وَابْنَ، عَبَّاسٍ وَأَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ تَذَاكَرُوا الْمُتَوَفَّى عَنْهَا زَوْجُهَا الْحَامِلَ تَضَعُ عِنْدَ وَفَاةِ زَوْجِهَا فَقَالَ ابْنُ عَبَّاسٍ تَعْتَدُّ آخِرَ الأَجَلَيْنِ ‏.‏ وَقَالَ أَبُو سَلَمَةَ بَلْ تَحِلُّ حِينَ تَضَعُ ‏.‏ وَقَالَ أَبُو هُرَيْرَةَ أَنَا مَعَ ابْنِ أَخِي يَعْنِي أَبَا سَلَمَةَ فَأَرْسَلُوا إِلَى أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ قَدْ وَضَعَتْ سُبَيْعَةُ الأَسْلَمِيَّةُ بَعْدَ وَفَاةِ زَوْجِهَا بِيَسِيرٍ فَاسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَمَرَهَا أَنْ تَتَزَوَّجَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ.‏\hadithno{1194}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sulaiman bin Yasir narrated that :Abu Hurairah, Ibn Abbas and Abu Salamah bin Abdur-Rahman mentioned the pregnant women whose husband died and she gave birth after the death of her husband. So Ibn Abbas said: "She observes Iddah until the end of the two terms." Abu Salamah said: "Rather, she is allowed when she gives birth." Abu Hurairah said: "I am with my nephew," meaning Abu Salamah.So he sent a message to Umm Salamah the wife of the Prophet. She said: "Subai'ah Al-Aslamiyyah gave birth a short time after her husband died, so she sought the judgment of the Messenger of Allah and he ordered her to get married}}
\hadithdefcmd{tirmidhi}{1195}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، أَنْبَأَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ بِهَذِهِ الأَحَادِيثِ الثَّلاَثَةِ، قَالَ قَالَتْ زَيْنَبُ دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُوهَا أَبُو سُفْيَانَ بْنُ حَرْبٍ فَدَعَتْ بِطِيبٍ فِيهِ صُفْرَةُ خَلُوقٍ أَوْ غَيْرُهُ فَدَهَنَتْ بِهِ جَارِيَةً ثُمَّ مَسَّتْ بِعَارِضَيْهَا ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثَةِ أَيَّامٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{1195}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Humaid bin Nafi narrated that :Zainab bint Abi Salamah said: "I entered upon Umm Habibah, the wife of the Prophet when her father Sufyan bin Harb died. So she asked for some perfume that had something yellow saffron or something else, so a girl applied it to her and put some on her cheeks. Then she said: 'By Allah! I have no need for perfume except that I heard the Messenger of Allah saying: "It is not lawful for a woman who believers in Allah and the Last Day to mourn for the dead more than three days, except for her husband (in which case it is) four months and ten days}}
\hadithdefcmd{tirmidhi}{1196}{قَالَتْ زَيْنَبُ فَدَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا فَدَعَتْ بِطِيبٍ فَمَسَّتْ مِنْهُ ثُمَّ قَالَتْ وَاللَّهِ مَا لِي فِي الطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{1196}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Humaid bin Nafi narrated that :Zainab said: "So I entered upon Zainab bint Jahsh when her brother died. She called for some perfume and put it on, then said: 'By Allah! I have no need for perfume except that I heard the Messenger of Allah said: "It is not lawful for a woman who believes in Allah and the Last Day to mourn for the dead more than three nights, except for her husband (in which case it is) four months and ten days}}
\hadithdefcmd{tirmidhi}{1197}{قَالَتْ زَيْنَبُ وَسَمِعْتُ أُمِّي أُمَّ سَلَمَةَ، تَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدِ اشْتَكَتْ عَيْنَيْهَا أَفَنَكْحَلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ مَرَّتَيْنِ أَوْ ثَلاَثَ مَرَّاتٍ كُلُّ ذَلِكَ يَقُولُ ‏"‏ لاَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا وَقَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَرْمِي بِالْبَعْرَةِ عَلَى رَأْسِ الْحَوْلِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ فُرَيْعَةَ بِنْتِ مَالِكٍ أُخْتِ أَبِي سَعِيدٍ الْخُدْرِيِّ وَحَفْصَةَ بِنْتِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ زَيْنَبَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ - وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْمُتَوَفَّى عَنْهَا زَوْجُهَا تَتَّقِي فِي عِدَّتِهَا الطِّيبَ وَالزِّينَةَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1197}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Humaid bin Nafi narrated that :Zainab said: "And I heard my mother, Umm Salamah said: 'A woman came to the Messenger of Allah and she said: "O Messenger of Allah! My daughter's husband died, and she is suffering from an eye ailment, so can she use Kohl?" the Messenger of Allah said: "No" two or three time. Each time (she asked) he said "no." Then he said: "It is just a mater of four months and ten (days). During Jahliyyah one of you would throw a clump of camel dung when one year passed}}
\hadithdefcmd{tirmidhi}{1198}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ سَلَمَةَ بْنِ صَخْرٍ الْبَيَاضِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْمُظَاهِرِ يُوَاقِعُ قَبْلَ أَنْ يُكَفِّرَ قَالَ ‏ "‏ كَفَّارَةٌ وَاحِدَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا وَاقَعَهَا قَبْلَ أَنْ يُكَفِّرَ فَعَلَيْهِ كَفَّارَتَانِ ‏.‏ وَهُوَ قَوْلُ عَبْدِ الرَّحْمَنِ بْنِ مَهْدِيٍّ ‏.‏\hadithno{1198}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Salamah bin Sakhr Al-Bayadi narrated:that the Prophet said, about the one who uttered Zihar and had intercourse before the atonement: "One atonement}}
\hadithdefcmd{tirmidhi}{1199}{أَنْبَأَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ مَعْمَرٍ، عَنِ الْحَكَمِ بْنِ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم قَدْ ظَاهَرَ مِنِ امْرَأَتِهِ فَوَقَعَ عَلَيْهَا فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ ظَاهَرْتُ مِنْ زَوْجَتِي فَوَقَعْتُ عَلَيْهَا قَبْلَ أَنْ أُكَفِّرَ ‏.‏ فَقَالَ ‏"‏ وَمَا حَمَلَكَ عَلَى ذَلِكَ يَرْحَمُكَ اللَّهُ ‏"‏ ‏.‏ قَالَ رَأَيْتُ خُلْخَالَهَا فِي ضَوْءِ الْقَمَرِ ‏.‏ قَالَ ‏"‏ فَلاَ تَقْرَبْهَا حَتَّى تَفْعَلَ مَا أَمَرَكَ اللَّهُ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{1199}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated that:A man came to the Prophet, and he had uttered Zihar upon his wife then he had intercourse with her. So he said: 'O Messenger of Allah! I uttered Zihar against my wife, then I had intercourse with her before atoning.' He (pbuh) said: "What caused you to do that, may Allah have mercy upon you?' He said: 'I saw her anklets in the moonlight.' He said: 'Then do not go near her until you have done what Allah ordered (for it)}}
\hadithdefcmd{tirmidhi}{1200}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا هَارُونُ بْنُ إِسْمَاعِيلَ الْخَزَّازُ، أَنْبَأَنَا عَلِيُّ بْنُ الْمُبَارَكِ، أَنْبَأَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنْبَأَنَا أَبُو سَلَمَةَ، وَمُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، أَنَّ سَلْمَانَ بْنَ صَخْرٍ الأَنْصَارِيَّ، أَحَدَ بَنِي بَيَاضَةَ جَعَلَ امْرَأَتَهُ عَلَيْهِ كَظَهْرِ أُمِّهِ حَتَّى يَمْضِيَ رَمَضَانُ فَلَمَّا مَضَى نِصْفٌ مِنْ رَمَضَانَ وَقَعَ عَلَيْهَا لَيْلاً فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْتِقْ رَقَبَةً ‏"‏ ‏.‏ قَالَ لاَ أَجِدُهَا ‏.‏ قَالَ ‏"‏ فَصُمْ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏ ‏.‏ قَالَ لاَ أَسْتَطِيعُ ‏.‏ قَالَ ‏"‏ أَطْعِمْ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏ قَالَ لاَ أَجِدُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِفَرْوَةَ بْنِ عَمْرٍو ‏"‏ أَعْطِهِ ذَلِكَ الْعَرَقَ ‏"‏ ‏.‏ وَهُوَ مِكْتَلٌ يَأْخُذُ خَمْسَةَ عَشَرَ صَاعًا أَوْ سِتَّةَ عَشَرَ صَاعًا فَقَالَ ‏"‏ أَطْعِمْ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ يُقَالُ سَلْمَانُ بْنُ صَخْرٍ وَيُقَالُ سَلَمَةُ بْنُ صَخْرٍ الْبَيَاضِيُّ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ فِي كَفَّارَةِ الظِّهَارِ ‏.‏\hadithno{1200}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Salamah and Muhammad bin Abdur-Rahman (bin Thawban) narrated that :Salman bin Sakhr Al-Ansari - from Banu Bayadah - said that his wife was like the back of his mother to him until Ramadan passed. After half of Ramadan had passed he had intercourse with his wife during the night. So he went to the Messenger of Allah to mention that to him. The Messenger of Allah said to him: "Free a slave." He said: "I don't have one." So he said: "Then fast two consecutive months." He said: "I am unable." He said: "Feed sixty needy people." He said: "I can not." So the Messenger of Allah said to Farwah bin Amr: "Give him that Araq - and it is a large basket that holds fifteen or sixteen Sa - to feed sixty needy people}}
\hadithdefcmd{tirmidhi}{1201}{حَدَّثَنَا الْحَسَنُ بْنُ قَزَعَةَ الْبَصْرِيُّ، أَنْبَأَنَا مَسْلَمَةُ بْنُ عَلْقَمَةَ، أَنْبَأَنَا دَاوُدُ بْنُ عَلِيٍّ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ آلَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نِسَائِهِ وَحَرَّمَ فَجَعَلَ الْحَرَامَ حَلاَلاً وَجَعَلَ فِي الْيَمِينِ كَفَّارَةً ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَأَبِي مُوسَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مَسْلَمَةَ بْنِ عَلْقَمَةَ عَنْ دَاوُدَ رَوَاهُ عَلِيُّ بْنُ مُسْهِرٍ وَغَيْرُهُ عَنْ دَاوُدَ عَنِ الشَّعْبِيِّ أَنَّ النَّبِيَّ صلى الله عليه وسلم ‏.‏ مُرْسَلاً ‏.‏ وَلَيْسَ فِيهِ عَنْ مَسْرُوقٍ عَنْ عَائِشَةَ وَهَذَا أَصَحُّ مِنْ حَدِيثِ مَسْلَمَةَ بْنِ عَلْقَمَةَ ‏.‏ وَالإِيلاَءُ هُوَ أَنْ يَحْلِفَ الرَّجُلُ أَنْ لاَ يَقْرُبَ امْرَأَتَهُ أَرْبَعَةَ أَشْهُرٍ فَأَكْثَرَ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِيهِ إِذَا مَضَتْ أَرْبَعَةُ أَشْهُرٍ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِذَا مَضَتْ أَرْبَعَةُ أَشْهُرٍ يُوقَفُ فَإِمَّا أَنْ يَفِيءَ وَإِمَّا أَنْ يُطَلِّقَ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِذَا مَضَتْ أَرْبَعَةُ أَشْهُرٍ فَهِيَ تَطْلِيقَةٌ بَائِنَةٌ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{1201}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"The Messenger of Allah swore Ila from his wives, and he made something unlawful and he made himself unlawful what was lawful, and he made atonement for his oath}}
\hadithdefcmd{tirmidhi}{1202}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ سُئِلْتُ عَنِ الْمُتَلاَعِنَيْنِ، فِي إِمَارَةِ مُصْعَبِ بْنِ الزُّبَيْرِ أَيُفَرَّقُ بَيْنَهُمَا فَمَا دَرَيْتُ مَا أَقُولُ فَقُمْتُ مَكَانِي إِلَى مَنْزِلِ عَبْدِ اللَّهِ بْنِ عُمَرَ اسْتَأْذَنْتُ عَلَيْهِ فَقِيلَ لِي إِنَّهُ قَائِلٌ ‏.‏ فَسَمِعَ كَلاَمِي فَقَالَ ابْنُ جُبَيْرٍ ادْخُلْ مَا جَاءَ بِكَ إِلاَّ حَاجَةٌ ‏.‏ قَالَ فَدَخَلْتُ فَإِذَا هُوَ مُفْتَرِشٌ بَرْدَعَةَ رَحْلٍ لَهُ ‏.‏ فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ الْمُتَلاَعِنَانِ أَيُفَرَّقُ بَيْنَهُمَا قَالَ سُبْحَانَ اللَّهِ نَعَمْ إِنَّ أَوَّلَ مَنْ سَأَلَ عَنْ ذَلِكَ فُلاَنُ بْنُ فُلاَنٍ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ لَوْ أَنَّ أَحَدَنَا رَأَى امْرَأَتَهُ عَلَى فَاحِشَةٍ كَيْفَ يَصْنَعُ إِنْ تَكَلَّمَ تَكَلَّمَ بِأَمْرٍ عَظِيمٍ وَإِنْ سَكَتَ سَكَتَ عَلَى أَمْرٍ عَظِيمٍ ‏.‏ قَالَ فَسَكَتَ النَّبِيُّ صلى الله عليه وسلم فَلَمْ يُجِبْهُ فَلَمَّا كَانَ بَعْدَ ذَلِكَ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ الَّذِي سَأَلْتُكَ عَنْهُ قَدِ ابْتُلِيتُ بِهِ ‏.‏ فَأَنْزَلَ اللَّهُ هَذِهِ الآيَاتِ الَّتِي فِي سُورَةِ النُّور ‏:‏ ‏(‏وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ وَلَمْ يَكُنْ لَهُمْ شُهَدَاءُ إِلاَّ أَنْفُسُهُمْ ‏)‏ حَتَّى خَتَمَ الآيَاتِ فَدَعَا الرَّجُلَ فَتَلاَ الآيَاتِ عَلَيْهِ وَوَعَظَهُ وَذَكَّرَهُ وَأَخْبَرَهُ أَنَّ عَذَابَ الدُّنْيَا أَهْوَنُ مِنْ عَذَابِ الآخِرَةِ ‏.‏ فَقَالَ لاَ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا كَذَبْتُ عَلَيْهَا ‏.‏ ثُمَّ ثَنَّى بِالْمَرْأَةِ فَوَعَظَهَا وَذَكَّرَهَا وَأَخْبَرَهَا أَنَّ عَذَابَ الدُّنْيَا أَهْوَنُ مِنْ عَذَابِ الآخِرَةِ فَقَالَتْ لاَ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا صَدَقَ ‏.‏ قَالَ فَبَدَأَ بِالرَّجُلِ فَشَهِدَ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الصَّادِقِينَ وَالْخَامِسَةُ أَنَّ لَعْنَةَ اللَّهِ عَلَيْهِ إِنْ كَانَ مِنَ الْكَاذِبِينَ ‏.‏ ثُمَّ ثَنَّى بِالْمَرْأَةِ فَشَهِدَتْ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الْكَاذِبِينَ وَالْخَامِسَةَ أَنَّ غَضَبَ اللَّهِ عَلَيْهَا إِنْ كَانَ مِنَ الصَّادِقِينَ ‏.‏ ثُمَّ فَرَّقَ بَيْنَهُمَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَهْلِ بْنِ سَعْدٍ وَابْنِ عَبَّاسٍ وَابْنِ مَسْعُودٍ وَحُذَيْفَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1202}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Sa'eed bin Jubair narrated:"I was asked about those who were involved in the case of Li'an and if they are to be separated, during the leadership of Mus'ab bin Az-Zubair. I did not know what to say. So I went to the house of Abdullah bin Umar and I sought permission to enter. I was told that he was taking a nap, but he heard me talking and he said: 'Is it Ibn Jubair? Enter. You would not have come except for a need.'"He said: "So I entered and found him lying on a saddlecloth from his mount. I said: 'O Abu Abdur-Rahman! Are those involved in Li'an separated?' He said: 'Glorious is Allah! Yes. The first who asked about that was so-and-so the son of so-and-so. He came to the Prophet and said: "O Messenger of Allah! If one of us saw his wife committing adultery what should he do? If he were to say anything, his statement would be a horrible matter, and if he were to remain silent, his silence about the matter would be horrible." "He said: 'So the Prophet remained silent and did not answer him. Afterwards he came to the Prophet and said: "The one who asked you about it has been tried by it." So Allah revealed these Ayat from Surat An-Nur. And those who accuse their wives and have no witnesses except themselves - until the end of those Ayat. So he called for the man and recited the Ayat to him and admonished him, reminded him, and he told him: "Indeed the punishment of the world is less than the punishment of the Hereafter." So he said: "Nay! By the One Who sent you with the truth! I did not lie about her." Then he did the same with the woman, admonished her and reminding her and he told her: "Indeed the punishment of the world is less than the punishment of the Hereafter." She said: "Nay! By the One Who sent you with the truth! He is not telling the truth.'" "He said: 'So he started with the man: He testified four times, by Allah that he is one of the truthful, and the fifth time that the curse of Allah be upon him if he was one of the liars. Then the same with the woman: She testified four times by Allah, that he was one of the liars, and the fifth time that the wrath of Allah be upon her if he was one of the truthful. Then he separated the two of them}}
\hadithdefcmd{tirmidhi}{1203}{أَنْبَأَنَا قُتَيْبَةُ، أَنْبَأَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لاَعَنَ رَجُلٌ امْرَأَتَهُ وَفَرَّقَ النَّبِيُّ صلى الله عليه وسلم بَيْنَهُمَا وَأَلْحَقَ الْوَلَدَ بِالأُمِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1203}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"A man pronounced the Li'an on his wife, and the Prophet separated the two of them, and he decide that the child belonged to the mother}}
\hadithdefcmd{tirmidhi}{1204}{حَدَّثَنَا الأَنْصَارِيُّ، أَنْبَأَنَا مَعْنٌ، أَنْبَأَنَا مَالِكٌ، عَنْ سَعْدِ بْنِ إِسْحَاقَ بْنِ كَعْبِ بْنِ عُجْرَةَ، عَنْ عَمَّتِهِ، زَيْنَبَ بِنْتِ كَعْبِ بْنِ عُجْرَةَ أَنَّ الْفُرَيْعَةَ بِنْتَ مَالِكِ بْنِ سِنَانٍ، وَهِيَ أُخْتُ أَبِي سَعِيدٍ الْخُدْرِيِّ أَخْبَرَتْهَا أَنَّهَا، جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم تَسْأَلُهُ أَنْ تَرْجِعَ إِلَى أَهْلِهَا فِي بَنِي خُدْرَةَ وَأَنَّ زَوْجَهَا خَرَجَ فِي طَلَبِ أَعْبُدٍ لَهُ أَبَقُوا حَتَّى إِذَا كَانَ بِطَرَفِ الْقَدُومِ لَحِقَهُمْ فَقَتَلُوهُ ‏.‏ قَالَتْ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ أَرْجِعَ إِلَى أَهْلِي فَإِنَّ زَوْجِي لَمْ يَتْرُكْ لِي مَسْكَنًا يَمْلِكُهُ وَلاَ نَفَقَةً ‏.‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَتْ فَانْصَرَفْتُ حَتَّى إِذَا كُنْتُ فِي الْحُجْرَةِ أَوْ فِي الْمَسْجِدِ نَادَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ أَمَرَ بِي فَنُودِيتُ لَهُ فَقَالَ ‏"‏ كَيْفَ قُلْتِ ‏"‏ ‏.‏ قَالَتْ فَرَدَدْتُ عَلَيْهِ الْقِصَّةَ الَّتِي ذَكَرْتُ لَهُ مِنْ شَأْنِ زَوْجِي قَالَ ‏"‏ امْكُثِي فِي بَيْتِكِ حَتَّى يَبْلُغَ الْكِتَابُ أَجَلَهُ ‏"‏ ‏.‏ قَالَتْ فَاعْتَدَدْتُ فِيهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏.‏ قَالَتْ فَلَمَّا كَانَ عُثْمَانُ أَرْسَلَ إِلَىَّ فَسَأَلَنِي عَنْ ذَلِكَ فَأَخْبَرْتُهُ فَاتَّبَعَهُ وَقَضَى بِهِ ‏.‏ أَنْبَأَنَا مُحَمَّدُ بْنُ بَشَّارٍ، أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، أَنْبَأَنَا سَعْدُ بْنُ إِسْحَاقَ بْنِ كَعْبِ بْنِ عُجْرَةَ، فَذَكَرَ نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لَمْ يَرَوْا لِلْمُعْتَدَّةِ أَنْ تَنْتَقِلَ مِنْ بَيْتِ زَوْجِهَا حَتَّى تَنْقَضِيَ عِدَّتُهَا ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لِلْمَرْأَةِ أَنْ تَعْتَدَّ حَيْثُ شَاءَتْ وَإِنْ لَمْ تَعْتَدَّ فِي بَيْتِ زَوْجِهَا ‏.‏ قَالَ أَبُو عِيسَى وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1204}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Zainab bint Ka'b bin Ujrah narrated that :Al-Furay'ah bint Malik bin Sinan - the sister of the Abu Sa'eed Al-Khudri - informed her that she went to the Messenger of Allah to ask him if she could return to her family in Banu Khudrah. Her husband had gone out searching for his runaway slaves, and when he was in Turaf Al-Qadum he caught up with them and they killed him. She said: "So I asked the Messenger of Allah if I could return to my family since my husband had not left me a home that he owned nor any maintenance." She said: "So the Messenger of Allah said: 'Yes.' Then I left. When I was in the courtyard," or, "in the Masjid, the Messenger of Allah called me" or, "summoned for me to come back t him and he said: 'What did you say?'" She said: "So I repeated the store that I had mentioned to him about the case of my husband. He said: 'Stay in your house until what is written reaches its term.'" She said: "So I observed my Iddah there for four months and ten (days)." She said: "During the time of Uthman, he sent a message to me asking me about that, so I informed him. He followed it and judged accordingly}}
